==> hazelcast-4.1.8-sources.jar: com/hazelcast/cp/internal/raftop/metadata/GetActiveRaftGroupByNameOp.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.cp.internal.raftop.metadata;

import com.hazelcast.cp.internal.IndeterminateOperationStateAware;
import com.hazelcast.cp.internal.MetadataRaftGroupManager;
import com.hazelcast.cp.internal.RaftServiceDataSerializerHook;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.nio.serialization.IdentifiedDataSerializable;

import java.io.IOException;

/**
 * Returns an active CP group by its name
 */
public class GetActiveRaftGroupByNameOp extends MetadataRaftGroupOp implements IndeterminateOperationStateAware,
                                                                               IdentifiedDataSerializable {

    private String groupName;

    public GetActiveRaftGroupByNameOp() {
    }

    public GetActiveRaftGroupByNameOp(String groupName) {
        this.groupName = groupName;
    }

    @Override
    public Object run(MetadataRaftGroupManager metadataGroupManager, long commitIndex) throws Exception {
        metadataGroupManager.checkMetadataGroupInitSuccessful();
        return metadataGroupManager.getActiveGroup(groupName);
    }

    @Override
    public boolean isRetryableOnIndeterminateOperationState() {
        return true;
    }

    @Override
    public int getFactoryId() {
        return RaftServiceDataSerializerHook.F_ID;
    }

    @Override
    public int getClassId() {
        return RaftServiceDataSerializerHook.GET_ACTIVE_RAFT_GROUP_BY_NAME_OP;
    }

    @Override
    public void writeData(ObjectDataOutput out) throws IOException {
        out.writeUTF(groupName);
    }

    @Override
    public void readData(ObjectDataInput in) throws IOException {
        groupName = in.readUTF();
    }

    @Override
    protected void toString(StringBuilder sb) {
        sb.append(", groupName=").append(groupName);
    }
}

==> hazelcast-5.1-sources.jar: com/hazelcast/cp/internal/raftop/metadata/GetActiveRaftGroupByNameOp.java <==
/*
 * Copyright (c) 2008-2022, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.cp.internal.raftop.metadata;

import com.hazelcast.cp.internal.IndeterminateOperationStateAware;
import com.hazelcast.cp.internal.MetadataRaftGroupManager;
import com.hazelcast.cp.internal.RaftServiceDataSerializerHook;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.nio.serialization.IdentifiedDataSerializable;

import java.io.IOException;

/**
 * Returns an active CP group by its name
 */
public class GetActiveRaftGroupByNameOp extends MetadataRaftGroupOp implements IndeterminateOperationStateAware,
                                                                               IdentifiedDataSerializable {

    private String groupName;

    public GetActiveRaftGroupByNameOp() {
    }

    public GetActiveRaftGroupByNameOp(String groupName) {
        this.groupName = groupName;
    }

    @Override
    public Object run(MetadataRaftGroupManager metadataGroupManager, long commitIndex) throws Exception {
        metadataGroupManager.checkMetadataGroupInitSuccessful();
        return metadataGroupManager.getActiveGroup(groupName);
    }

    @Override
    public boolean isRetryableOnIndeterminateOperationState() {
        return true;
    }

    @Override
    public int getFactoryId() {
        return RaftServiceDataSerializerHook.F_ID;
    }

    @Override
    public int getClassId() {
        return RaftServiceDataSerializerHook.GET_ACTIVE_RAFT_GROUP_BY_NAME_OP;
    }

    @Override
    public void writeData(ObjectDataOutput out) throws IOException {
        out.writeString(groupName);
    }

    @Override
    public void readData(ObjectDataInput in) throws IOException {
        groupName = in.readString();
    }

    @Override
    protected void toString(StringBuilder sb) {
        sb.append(", groupName=").append(groupName);
    }
}
